==> dagger-compiler-2.44-sources.jar: dagger/internal/codegen/binding/AutoValue_ProductionBinding.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XType;
import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ContributionType;
import dagger.spi.model.BindingKind;
import dagger.spi.model.DaggerAnnotation;
import dagger.spi.model.DependencyRequest;
import dagger.spi.model.Key;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;

final class AutoValue_ProductionBinding extends $AutoValue_ProductionBinding {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean requiresModuleInstance;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean requiresModuleInstance$Memoized;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int hashCode;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean hashCode$Memoized;

  AutoValue_ProductionBinding(ContributionType contributionType$, Key key$,
      Optional<XElement> bindingElement$, Optional<XTypeElement> contributingModule$,
      BindingKind kind$, ImmutableSet<DependencyRequest> explicitDependencies$,
      Optional<XType> nullableType$, Optional<DaggerAnnotation> mapKey$,
      Optional<ProductionBinding> unresolved$,
      Optional<ProductionBinding.ProductionKind> productionKind$, ImmutableList<XType> thrownTypes$,
      Optional<DependencyRequest> executorRequest$, Optional<DependencyRequest> monitorRequest$) {
    super(contributionType$, key$, bindingElement$, contributingModule$, kind$, explicitDependencies$, nullableType$, mapKey$, unresolved$, productionKind$, thrownTypes$, executorRequest$, monitorRequest$);
  }

  @Override
  public boolean requiresModuleInstance() {
    if (!requiresModuleInstance$Memoized) {
      synchronized (this) {
        if (!requiresModuleInstance$Memoized) {
          requiresModuleInstance = super.requiresModuleInstance();
          requiresModuleInstance$Memoized = true;
        }
      }
    }
    return requiresModuleInstance;
  }

  @Override
  public int hashCode() {
    if (!hashCode$Memoized) {
      synchronized (this) {
        if (!hashCode$Memoized) {
          hashCode = super.hashCode();
          hashCode$Memoized = true;
        }
      }
    }
    return hashCode;
  }

  @Override
  public boolean equals(Object that) {
    if (this == that) {
      return true;
    }
    return that instanceof AutoValue_ProductionBinding && this.hashCode() == that.hashCode() && super.equals(that);
  }
}

==> dagger-compiler-2.51.1-sources.jar: dagger/internal/codegen/binding/AutoValue_ProductionBinding.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XElement;
import androidx.room.compiler.processing.XType;
import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableSet;
import com.google.errorprone.annotations.concurrent.LazyInit;
import dagger.internal.codegen.base.ContributionType;
import dagger.internal.codegen.model.BindingKind;
import dagger.internal.codegen.model.DaggerAnnotation;
import dagger.internal.codegen.model.DependencyRequest;
import dagger.internal.codegen.model.Key;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;
import java.util.Optional;

final class AutoValue_ProductionBinding extends $AutoValue_ProductionBinding {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean requiresModuleInstance;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean requiresModuleInstance$Memoized;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile int hashCode;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean hashCode$Memoized;

  AutoValue_ProductionBinding(ContributionType contributionType$, Key key$,
      Optional<XElement> bindingElement$, Optional<XTypeElement> contributingModule$,
      BindingKind kind$, ImmutableSet<DependencyRequest> explicitDependencies$,
      Nullability nullability$, Optional<DaggerAnnotation> mapKey$,
      Optional<ProductionBinding> unresolved$,
      Optional<ProductionBinding.ProductionKind> productionKind$, ImmutableList<XType> thrownTypes$,
      Optional<DependencyRequest> executorRequest$, Optional<DependencyRequest> monitorRequest$) {
    super(contributionType$, key$, bindingElement$, contributingModule$, kind$, explicitDependencies$, nullability$, mapKey$, unresolved$, productionKind$, thrownTypes$, executorRequest$, monitorRequest$);
  }

  @Override
  public boolean requiresModuleInstance() {
    if (!requiresModuleInstance$Memoized) {
      synchronized (this) {
        if (!requiresModuleInstance$Memoized) {
          requiresModuleInstance = super.requiresModuleInstance();
          requiresModuleInstance$Memoized = true;
        }
      }
    }
    return requiresModuleInstance;
  }

  @Override
  public int hashCode() {
    if (!hashCode$Memoized) {
      synchronized (this) {
        if (!hashCode$Memoized) {
          hashCode = super.hashCode();
          hashCode$Memoized = true;
        }
      }
    }
    return hashCode;
  }

  @Override
  public boolean equals(Object that) {
    if (this == that) {
      return true;
    }
    return that instanceof AutoValue_ProductionBinding && this.hashCode() == that.hashCode() && super.equals(that);
  }
}
